from grafanalib.core import Panel
from .row import Row

def row3(*args: Panel):
    return Row(3, *args)


def row4(*args: Panel):
    return Row(4, *args)


def row5(*args: Panel):
    return Row(5, *args)


def row6(*args: Panel):
    return Row(6, *args)


def row7(*args: Panel):
    return Row(7, *args)


def row8(*args: Panel):
    return Row(8, *args)
